#ifndef BLMSPF_H
#define BLMSPF_H

#ifdef _USRDLL
#define BLMSPF_API __declspec(dllexport)
#else
#define BLMSPF_API __declspec(dllimport)
#endif

#define MAX_BLMSPF_ERROR				1024
#define MAX_BLMSPF_VERSION				32
#define BLMSPF_PASSWORD_LENGTH			32
#define	DEFAULT_BLMSPF_BAUD				9600

#define BLMSPF_NULL_ID					0
#define BLMSPF_HOST_ID					1
#define BLMSPF_REMOTE_ID				2

#define BLMSPF_FILE_TYPE_TI_TEXT		1
#define BLMSPF_FILE_TYPE_INTEL_HEX		2

#define BLMSPF_MSG_TYPE_TEXT			0x00000001
#define BLMSPF_MSG_TYPE_NAMED_TEXT		0x00000002
#define BLMSPF_MSG_TYPE_BUFFER			0x00000004
#define BLMSPF_MSG_TYPE_PROGRESS		0x00000008
#define BLMSPF_MSG_TYPE_ALL				0xFFFFFFFF

#define BLMSPF_PROGRESS_TYPE_INIT_TARGET	201
#define BLMSPF_PROGRESS_TYPE_RESET_TARGET	202
#define BLMSPF_PROGRESS_TYPE_WRITE_FILE		203
#define BLMSPF_PROGRESS_TYPE_READ_FILE		204
#define BLMSPF_PROGRESS_TYPE_VERIFY_FILE	205

// Callback messages use SendMessage to call the handler immediately
// WPARAM is message type

typedef struct tagBLMSPF_MSG_TEXT
{	BOOL bCRLF;
	LPCTSTR szText;
} BLMSPF_MSG_TEXT; 

typedef struct tagBLMSPF_MSG_NAMEDTEXT
{	int nID;
	LPCTSTR szText;
} BLMSPF_MSG_NAMEDTEXT; 

typedef struct tagBLMSPF_MSG_BUFFER
{	int nID;
	DWORD dwSize;
	LPBYTE pbyBuffer;
} BLMSPF_MSG_BUFFER; 

typedef struct tagBLMSPF_MSG_PROGRESS
{	int nProgressType;
	int nProgress;
	int nMax;
} BLMSPF_MSG_PROGRESS; 

#ifdef __cplusplus
extern "C" 
{
#endif /* __cplusplus */

BLMSPF_API BOOL Open_BLMSPF( LPCTSTR szPort, DWORD dwBaud );
BLMSPF_API void Close_BLMSPF( void );
BLMSPF_API BOOL IsOpen_BLMSPF();
BLMSPF_API DWORD GetLastError_BLMSPF( LPTSTR szBuffer, DWORD dwBufferSize );
BLMSPF_API LPCTSTR GetVersion_BLMSPF( void );
BLMSPF_API void RegisterHWND_BLMSPF( HWND hWnd, UINT nMsgID, DWORD dwMask );

BLMSPF_API BOOL SetPatchFile_BLMSPF( LPCTSTR szPatchFileName );
BLMSPF_API BOOL InitializeAdapter_BLMSPF();
BLMSPF_API BOOL GetAdapterInfo_BLMSPF( LPWORD pwVersion, LPDWORD pdwSerNum );
BLMSPF_API BOOL ResetTarget_BLMSPF();
BLMSPF_API BOOL PowerOn_BLMSPF();
BLMSPF_API BOOL PowerOff_BLMSPF();
BLMSPF_API BOOL SetPasswordData_BLMSPF( LPBYTE abyPassword );
BLMSPF_API BOOL GetPasswordData_BLMSPF( LPBYTE pBuffer, DWORD dwBufferSize, LPDWORD pdwBytesRead );
BLMSPF_API BOOL GetBootloaderVersion_BLMSPF( LPBYTE pMajorVersion, LPBYTE pMinorVersion );
BLMSPF_API LPCTSTR GetProcessorType_BLMSPF();
BLMSPF_API BOOL InitializeTarget_BLMSPF( BOOL bForcePower );
BLMSPF_API BOOL MassErase_BLMSPF();
BLMSPF_API BOOL WriteFile_BLMSPF( LPCTSTR szFileName, int nFileType, BOOL bWithVerify );
BLMSPF_API BOOL ReadFile_BLMSPF( LPCTSTR szFileName, int nFileType, DWORD dwAddress, DWORD dwSize );
BLMSPF_API BOOL VerifyFile_BLMSPF( LPCTSTR szFileName, int nFileType );
BLMSPF_API BOOL SetPasswordFile_BLMSPF( LPCTSTR szFileName, int nFileType );

BLMSPF_API BOOL IsPatchRequired_BLMSPF();
BLMSPF_API BOOL LoadPC_BLMSPF( DWORD dwAddress );
BLMSPF_API BOOL SectorErase_BLMSPF( DWORD dwSectorAddress );
BLMSPF_API BOOL RxData_BLMSPF( DWORD dwAddress, LPBYTE pBuffer, DWORD dwCount, LPDWORD pdwBytesRead );
BLMSPF_API BOOL TxData_BLMSPF( DWORD dwAddress, LPBYTE pBuffer, DWORD dwCount, BOOL bWithVerify );
BLMSPF_API BOOL VerifyData_BLMSPF( DWORD dwAddress, LPBYTE pBuffer, DWORD dwCount );

BLMSPF_API BOOL PollTargetSignal_BLMSPF( LPBOOL pbSignal );
BLMSPF_API BOOL PortTx_BLMSPF( LPBOOL pbSignal, LPBYTE pBuffer, DWORD dwCount );
BLMSPF_API BOOL PortRx_BLMSPF( LPBOOL pbSignal, LPBYTE pBuffer, DWORD dwCount, LPDWORD pdwBytesRead );

#ifdef __cplusplus
} /* End of extern "C" { */
#endif /* __cplusplus */

#endif
